@@ -27,16 +27,18 @@
 #############################################################################
 
 setGeneric("appendNamedRegion",
-	function(object, data, name, header = FALSE, rownames = NULL) standardGeneric("appendNamedRegion"))
+	function(object, data, name, header = FALSE, overwriteFormulaCells = TRUE,
+	         rownames = NULL) standardGeneric("appendNamedRegion"))
 
 setMethod("appendNamedRegion", 
 	signature(object = "workbook", data = "ANY"), 
-	function(object, data, name, header = FALSE, rownames = NULL) {
+	function(object, data, name, header = FALSE, overwriteFormulaCells = TRUE,
+	         rownames = NULL) {
 		if(is.character(rownames))
 			data <- includeRownames(data, rownames)
 		# pass data.frame's to Java - construct RDataFrameWrapper Java object references
 		data <- lapply(wrapList(data), dataframeToJava)
-		xlcCall(object, "appendNamedRegion", data, name, header, .simplify = FALSE)
+		xlcCall(object, "appendNamedRegion", data, name, header, overwriteFormulaCells, .simplify = FALSE)
 		invisible()
 	}
 )
